@@ -413,7 +413,7 @@ class MathStructure {
 		void childToFront(size_t index);
 		void addChild(const MathStructure &o);
 		void addChild_nocopy(MathStructure *o);
-		void delChild(size_t index);
+		void delChild(size_t index, bool check_size = false);
 		void insertChild(const MathStructure &o, size_t index);
 		void insertChild_nocopy(MathStructure *o, size_t index);
 		void setChild(const MathStructure &o, size_t index = 1, bool merge_precision = false);
@@ -486,8 +486,10 @@ class MathStructure {
 		bool representsNonNegative(bool allow_units = false) const;
 		bool representsNonPositive(bool allow_units = false) const;
 		bool representsInteger(bool allow_units = false) const;
+		bool representsNonInteger(bool allow_units = false) const;
 		bool representsNumber(bool allow_units = false) const;
 		bool representsRational(bool allow_units = false) const;
+		bool representsFraction(bool allow_units = false) const;
 		bool representsReal(bool allow_units = false) const;
 		bool representsComplex(bool allow_units = false) const;
 		bool representsNonZero(bool allow_units = false) const;
@@ -628,7 +630,7 @@ class MathStructure {
 		bool equals(string sym) const;
 		
 		ComparisonResult compare(const MathStructure &o) const;
-		ComparisonResult compareApproximately(const MathStructure &o) const;
+		ComparisonResult compareApproximately(const MathStructure &o, const EvaluationOptions &eo = default_evaluation_options) const;
 
 		bool operator == (const MathStructure &o) const;
 		bool operator == (const Number &o) const;
@@ -765,7 +767,7 @@ class MathStructure {
 
 		/** @name Functions for unit conversion */
 		//@{
-		int isUnitCompatible(const MathStructure &mstruct);
+		int isUnitCompatible(const MathStructure &mstruct) const;
 		bool syncUnits(bool sync_complex_relations = false, bool *found_complex_relations = NULL, bool calculate_new_functions = false, const EvaluationOptions &feo = default_evaluation_options);
 		bool testDissolveCompositeUnit(Unit *u);
 		bool testCompositeUnit(Unit *u);	
@@ -811,7 +813,7 @@ class MathStructure {
 		/** @name Functions for polynomials */
 		//@{
 		bool simplify(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true);
-		bool factorize(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true, int term_combination_levels = -1, int max_msecs = 1000, bool only_integers = true, bool recursive = true, struct timeval *endtime_p = NULL);
+		bool factorize(const EvaluationOptions &eo = default_evaluation_options, bool unfactorize = true, int term_combination_levels = 0, int max_msecs = 1000, bool only_integers = true, int recursive = 1, struct timeval *endtime_p = NULL);
 		bool structure(StructuringMode structuring, const EvaluationOptions &eo, bool restore_first = true);
 		/** If the structure represents a rational polynomial.
 		* This is true for
